# -*- coding: utf-8 -*-
import os
import sys

sys.path.append(os.path.dirname(os.path.realpath(__file__)))  # noqa: PTH120

import files  # noqa: E402
import languages  # noqa: E402
import argparser  # noqa: E402
import settings  # noqa: E402
